==> rest-sdk-web-api-0.8.0-sources.jar: com/mulesoft/connectivity/rest/sdk/internal/webapi/model/APIParameterModel.java <==
/*
 * (c) 2003-2021 MuleSoft, Inc. This software is protected under international copyright
 * law. All use of this software is subject to MuleSoft's Master Subscription Agreement
 * (or other master license agreement) separately entered into in writing between you and
 * MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package com.mulesoft.connectivity.rest.sdk.internal.webapi.model;

import com.mulesoft.connectivity.rest.sdk.internal.webapi.model.type.APITypeModel;
import com.mulesoft.connectivity.rest.sdk.internal.webapi.model.type.APIParameterType;

public abstract class APIParameterModel {

  protected String externalName;
  protected String displayName;
  protected APIParameterType parameterType;
  protected String description;
  protected boolean isRequired;
  protected String defaultValue;
  protected boolean isPassword;
  protected APITypeModel typeModel;
  protected String summary;

  public String getExternalName() {
    return externalName;
  }

  public String getDisplayName() {
    return displayName;
  }

  public APIParameterType getParameterType() {
    return parameterType;
  }

  public String getDescription() {
    return description;
  }

  public String getDefaultValue() {
    return defaultValue;
  }

  public APITypeModel getTypeModel() {
    return typeModel;
  }

  public boolean isRequired() {
    return isRequired;
  }

  public boolean isPassword() {
    return isPassword;
  }

  public String getSummary() {
    return summary;
  }
}

==> rest-sdk-web-api-0.12.0-20250401.143830-3-sources.jar: com/mulesoft/connectivity/rest/sdk/internal/webapi/model/APIParameterModel.java <==
/*
 * (c) 2003-2021 MuleSoft, Inc. This software is protected under international copyright
 * law. All use of this software is subject to MuleSoft's Master Subscription Agreement
 * (or other master license agreement) separately entered into in writing between you and
 * MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package com.mulesoft.connectivity.rest.sdk.internal.webapi.model;

import com.mulesoft.connectivity.rest.sdk.internal.webapi.model.type.APITypeModel;
import com.mulesoft.connectivity.rest.sdk.internal.webapi.model.type.APIParameterType;

public abstract class APIParameterModel {

  protected String externalName;
  protected String displayName;
  protected APIParameterType parameterType;
  protected String description;
  protected boolean isRequired;
  protected String defaultValue;
  protected boolean isPassword;
  protected APITypeModel typeModel;
  protected String summary;

  public String getExternalName() {
    return externalName;
  }

  public String getDisplayName() {
    return displayName;
  }

  public APIParameterType getParameterType() {
    return parameterType;
  }

  public String getDescription() {
    return description;
  }

  public String getDefaultValue() {
    return defaultValue;
  }

  public APITypeModel getTypeModel() {
    return typeModel;
  }

  public boolean isRequired() {
    return isRequired;
  }

  public boolean isPassword() {
    return isPassword;
  }

  public String getSummary() {
    return summary;
  }

  /**
   * Retrieves the location in the API Spec this element was parsed from.
   */
  public abstract APILocation getLocation();
}
